pub struct Recommendation(/* private fields */);Expand description
Human-readable recommendation proposed for staff or manager review.
Recommendations are labor-cost levers only after the surrounding workflow decides whether they remain drafts, become staff tasks, or require manager approval.
Implementations
Sourceimpl Recommendation
impl Recommendation
pub fn into_inner(self) -> String